Index: lib/matplotlib/pyplot.py
===================================================================
--- lib/matplotlib/pyplot.py	(revision 7068)
+++ lib/matplotlib/pyplot.py	(working copy)
@@ -1447,8 +1447,8 @@
     draw_if_interactive()
     return ret
 
-def plotfile(fname, cols=(0,), plotfuncs=None,
-             comments='#', skiprows=0, checkrows=5, delimiter=',',
+def plotfile(fname, cols=(0,), plotfuncs=None, use_cf=False,
+             comments='#', skiprows=0, checkrows=5, delimiter=',', names=None,
              **kwargs):
     """
     Plot the data in *fname*
@@ -1473,9 +1473,12 @@
     vector as you use in the *plotfuncs* dictionary, eg., integer
     column numbers in both or column names in both.
 
-    *comments*, *skiprows*, *checkrows*, and *delimiter* are all passed on to
-    :func:`matplotlib.pylab.csv2rec` to load the data into a record array.
+    *use_cf* : use current figure instead of a new figure for plotting
 
+    *comments*, *skiprows*, *checkrows*, *delimiter*, and *names* are all
+    passed on to :func:`matplotlib.pylab.csv2rec` to load the data into a
+    record array. 
+
     kwargs are passed on to plotting functions.
 
     Example usage::
@@ -1484,17 +1487,21 @@
       plotfile(fname, (0,1,3))
 
       # plot using column names; specify an alternate plot type for volume
-      plotfile(fname, ('date', 'volume', 'adj_close'), plotfuncs={'volume': 'semilogy'})
+      plotfile(fname, ('date', 'volume', 'adj_close'),
+               plotfuncs={'volume': 'semilogy'})
     """
+    if use_cf is False:
+        fig = figure()
+    else:
+        fig = gcf()
 
-    fig = figure()
     if len(cols)<1:
         raise ValueError('must have at least one column of data')
 
     if plotfuncs is None:
         plotfuncs = dict()
-    r = mlab.csv2rec(fname, comments=comments,
-                skiprows=skiprows, checkrows=checkrows, delimiter=delimiter)
+    r = mlab.csv2rec(fname, comments=comments, skiprows=skiprows,
+                     checkrows=checkrows, delimiter=delimiter, names=names)
 
     def getname_val(identifier):
         'return the name and column data for identifier'
